@@ -5,8 +5,9 @@ import click
 from tabulate import tabulate
 
 from . import MySQLtoSQLite
-from .click_utils import OptionEatAll, prompt_password
+from .click_utils import OptionEatAll, prompt_password, validate_positive_integer
 from .debug_info import info
+from .sqlite_utils import CollatingSequences
 
 
 @click.command()
@@ -38,6 +39,29 @@ from .debug_info import info
     help="Transfer only these specific tables (space separated table names). "
     "Implies --without-foreign-keys which inhibits the transfer of foreign keys.",
 )
+@click.option(
+    "-L",
+    "--limit-rows",
+    type=int,
+    callback=validate_positive_integer,
+    default=0,
+    help="Transfer only a limited number of rows from each table.",
+)
+@click.option(
+    "-C",
+    "--collation",
+    type=click.Choice(
+        [
+            CollatingSequences.BINARY,
+            CollatingSequences.NOCASE,
+            CollatingSequences.RTRIM,
+        ],
+        case_sensitive=False,
+    ),
+    default=CollatingSequences.BINARY,
+    show_default=True,
+    help="Create datatypes of TEXT affinity using a specified collation sequence.",
+)
 @click.option(
     "-X", "--without-foreign-keys", is_flag=True, help="Do not transfer foreign keys."
 )
@@ -83,6 +107,8 @@ def cli(
     mysql_password,
     mysql_database,
     mysql_tables,
+    limit_rows,
+    collation,
     without_foreign_keys,
     mysql_host,
     mysql_port,
@@ -101,6 +127,8 @@ def cli(
             mysql_password=mysql_password or prompt_mysql_password,
             mysql_database=mysql_database,
             mysql_tables=mysql_tables,
+            limit_rows=limit_rows,
+            collation=collation,
             without_foreign_keys=without_foreign_keys
             or (mysql_tables is not None and len(mysql_tables) > 0),
             mysql_host=mysql_host,
