@@ -17,6 +17,7 @@ from mysql.connector import errorcode
 from tqdm import tqdm, trange
 
 from mysql_to_sqlite3.sqlite_utils import (
+    CollatingSequences,
     adapt_decimal,
     adapt_timedelta,
     convert_decimal,
@@ -50,6 +51,17 @@ class MySQLtoSQLite:
             else tuple()
         )
 
+        self._limit_rows = int(kwargs.get("limit_rows") or 0)
+
+        if kwargs.get("collation") is not None and kwargs.get("collation").upper() in {
+            CollatingSequences.BINARY,
+            CollatingSequences.NOCASE,
+            CollatingSequences.RTRIM,
+        }:
+            self._collation = kwargs.get("collation").upper()
+        else:
+            self._collation = CollatingSequences.BINARY
+
         self._without_foreign_keys = (
             True
             if len(self._mysql_tables) > 0
@@ -242,6 +254,23 @@ class MySQLtoSQLite:
                 return "DEFAULT {}".format(column_default.upper())
         return "DEFAULT '{}'".format(column_default)
 
+    @classmethod
+    def _data_type_collation_sequence(
+        cls, collation=CollatingSequences.BINARY, column_type=None
+    ):
+        if column_type and collation != CollatingSequences.BINARY:
+            if column_type.startswith(
+                (
+                    "CHARACTER",
+                    "NCHAR",
+                    "NVARCHAR",
+                    "TEXT",
+                    "VARCHAR",
+                )
+            ):
+                return "COLLATE {collation}".format(collation=collation)
+        return ""
+
     def _build_create_table_sql(self, table_name):
         sql = 'CREATE TABLE IF NOT EXISTS "{}" ('.format(table_name)
         primary = ""
@@ -251,13 +280,16 @@ class MySQLtoSQLite:
 
         for row in self._mysql_cur_dict.fetchall():
             column_type = self._translate_type_from_mysql_to_sqlite(row["Type"])
-            sql += '\n\t"{name}" {type} {notnull} {default},'.format(
+            sql += '\n\t"{name}" {type} {notnull} {default} {collation},'.format(
                 name=row["Field"],
                 type=column_type,
                 notnull="NULL" if row["Null"] == "YES" else "NOT NULL",
                 default=self._translate_default_from_mysql_to_sqlite(
                     row["Default"], column_type
                 ),
+                collation=self._data_type_collation_sequence(
+                    self._collation, column_type
+                ),
             )
 
         self._mysql_cur_dict.execute(
@@ -474,16 +506,37 @@ class MySQLtoSQLite:
                 self._create_table(table_name)
 
                 # get the size of the data
-                self._mysql_cur_dict.execute(
-                    "SELECT COUNT(*) AS `total_records` FROM `{}`".format(table_name)
-                )
+                if self._limit_rows > 0:
+                    # limit to the requested number of rows
+                    self._mysql_cur_dict.execute(
+                        """
+                            SELECT COUNT(*) AS `total_records`
+                            FROM (SELECT * FROM `{table_name}` LIMIT {limit}) AS `table`
+                        """.format(
+                            table_name=table_name, limit=self._limit_rows
+                        )
+                    )
+                else:
+                    # get all rows
+                    self._mysql_cur_dict.execute(
+                        "SELECT COUNT(*) AS `total_records` FROM `{table_name}`".format(
+                            table_name=table_name
+                        )
+                    )
                 total_records = int(self._mysql_cur_dict.fetchone()["total_records"])
 
                 # only continue if there is anything to transfer
                 if total_records > 0:
                     # populate it
                     self._logger.info("Transferring table %s", table_name)
-                    self._mysql_cur.execute("SELECT * FROM `{}`".format(table_name))
+                    self._mysql_cur.execute(
+                        "SELECT * FROM `{table_name}` {limit}".format(
+                            table_name=table_name,
+                            limit="LIMIT {}".format(self._limit_rows)
+                            if self._limit_rows > 0
+                            else "",
+                        )
+                    )
                     columns = [column[0] for column in self._mysql_cur.description]
                     # build the SQL string
                     sql = """
